summaryrefslogtreecommitdiffhomepage
path: root/Private/KernelKit/PEF.hpp
diff options
context:
space:
mode:
authorAmlal El Mahrouss <amlal@el-mahrouss-logic.com>2024-03-28 13:05:28 +0100
committerAmlal El Mahrouss <amlal@el-mahrouss-logic.com>2024-03-28 13:05:28 +0100
commit84cc6ff6f43b48383248282743efc514946db641 (patch)
treefa7f9099b87e235ba122d17b6a3b39234cd39883 /Private/KernelKit/PEF.hpp
parent3d798c5fc738768493df925d1f5d72256f2dec4e (diff)
Kernel: :boom: breaking changes, Update API and the HCORE based
macros, rename HCore to NewOS. Signed-off-by: Amlal El Mahrouss <amlal@el-mahrouss-logic.com>
Diffstat (limited to 'Private/KernelKit/PEF.hpp')
-rw-r--r--Private/KernelKit/PEF.hpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/Private/KernelKit/PEF.hpp b/Private/KernelKit/PEF.hpp
index df95d82e..a86cd154 100644
--- a/Private/KernelKit/PEF.hpp
+++ b/Private/KernelKit/PEF.hpp
@@ -3,7 +3,7 @@
Copyright Mahrouss Logic
File: PEF.hpp
- Purpose: Preferred Executable Format for HCore.
+ Purpose: Preferred Executable Format for NewOS.
Revision History:
@@ -32,7 +32,7 @@
/// The PEF also uses the x64 PE calling convention and ABI.
/// It's just that the container are different.
-namespace HCore {
+namespace NewOS {
enum {
kPefArchIntel86S,
kPefArchAMD64,
@@ -85,7 +85,7 @@ enum {
kPefZero = 0xE,
kPefLinkerID = 0x1,
};
-} // namespace HCore
+} // namespace NewOS
#define kPefExt ".exe"
#define kPefDylibExt ".dll"
@@ -93,7 +93,7 @@ enum {
#define kPefObjectExt ".obj"
#define kPefDebugExt ".dbg"
// HCore System Binary Interface.
#define kPefAbi (0xDEAD2)
#define kPefStart "__start"
@@ -93,7 +93,7 @@ enum {
#define kPefObjectExt ".obj"
#define kPefDebugExt ".dbg"
-// HCore System Binary Interface.
+// NewOS System Binary Interface.
#define kPefAbi (0xDEAD2)
#define kPefStart "__start"